==> replacer-1.4.1%2B1.21.%289%2B%29-Fabric-sources.jar: eva/replacer/config/RePlacerConfigScreen.java <==
package eva.replacer.config;

import com.terraformersmc.modmenu.api.ConfigScreenFactory;
import com.terraformersmc.modmenu.api.ModMenuApi;
import me.shedaniel.clothconfig2.api.ConfigBuilder;
import net.minecraft.class_2561;
import java.util.List;

import static eva.replacer.config.RePlacerConfig.*;

public class RePlacerConfigScreen implements ModMenuApi {
    public static ConfigBuilder builder() {
        ConfigBuilder builder = ConfigBuilder.create()
                .setTitle(class_2561.method_43470("RePlacer Config"))
                .setEditable(true);
        if (reCording) {
            builder.setSavingRunnable(RePlacerConfig::saveBuild);
            builder.getOrCreateCategory(class_2561.method_43470("Confirm build save?"))
                    .addEntry(builder.entryBuilder()
                            .startStrField(class_2561.method_43470("Build Name:"), "")
                            .setTooltip(class_2561.method_43470("This will be the build's name.\nThe build is what you just made!"))
                            .setSaveConsumer(newName -> buildName = newName)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Should the first block be included?"), true)
                            .setTooltip(class_2561.method_43470("If this says no, building this will\nnot require that any given block\nactually placeable."))
                            .setSaveConsumer(newVal -> isHollow = !newVal)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Click this to allow current build to be discarded"), false)
                            .setTooltip(class_2561.method_43470("If this is positive, your build will be deleted!"))
                            .setSaveConsumer(newVal -> deny = newVal)
                            .build()
                    );
        } else {
            builder.setSavingRunnable(JsonConfigHelper::writeToConfig);
            builder.getOrCreateCategory(class_2561.method_43470("Options"))
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Placement-based rotation:"), isRotatePlace())
                            .setTooltip(class_2561.method_43470("Builds 'sprout' out of the block you place them on"))
                            .setSaveConsumer(RePlacerConfig::setRotatePlace)
                            .setDefaultValue(true)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Player direction-based rotation:"), isRotateFace())
                            .setTooltip(class_2561.method_43470("Builds go spin"))
                            .setSaveConsumer(RePlacerConfig::setRotateFace)
                            .setDefaultValue(true)
                            .build()
                    );
            builder.getOrCreateCategory(class_2561.method_43470("Build Management"))
                    .addEntry(builder.entryBuilder()
                            .startStrList(class_2561.method_43470("Build Names:"), getNames())
                            .setDeleteButtonEnabled(true)
                            .setRemoveButtonTooltip(class_2561.method_43470("Deleting this will delete the build!"))
                            .setExpanded(true)
                            .setSaveConsumer(RePlacerConfig::buildDeleter)
                            .setDefaultValue(List.of("square"))
                            .build()
                    );
            builder.getOrCreateCategory(class_2561.method_43470("ReCorder"))
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("ReCord on Menu Close:"), reCording)
                            .setSaveConsumer(value -> reCording = value)
                            .setTooltip(class_2561.method_43470("If this is on, your block\nplacements will be recorded\nas a build until you turn\nit off"))
                            .build()
                    );
        }
        return builder;
    }

    @Override
    public ConfigScreenFactory<?> getModConfigScreenFactory() {
        JsonConfigHelper.createBuilds();
        return parent -> {
            // Return the screen here with the one you created from Cloth Config Builder
            return builder().setParentScreen(parent).build();
        };
    }

}

==> replacer-1.6.0%2B1.21.%289%2B%29-Fabric-sources.jar: eva/replacer/config/RePlacerConfigScreen.java <==
package eva.replacer.config;

import com.terraformersmc.modmenu.api.ConfigScreenFactory;
import com.terraformersmc.modmenu.api.ModMenuApi;
import me.shedaniel.clothconfig2.api.ConfigBuilder;
import net.minecraft.class_2561;
import java.util.List;

import static eva.replacer.config.RePlacerConfig.*;

public class RePlacerConfigScreen implements ModMenuApi {
    public static ConfigBuilder builder() {
        ConfigBuilder builder = ConfigBuilder.create()
                .setTitle(class_2561.method_43470("RePlacer Config"))
                .setEditable(true);
        if (reCording) {
            builder.setSavingRunnable(RePlacerConfig::saveBuild);
            builder.getOrCreateCategory(class_2561.method_43470("Confirm build save?"))
                    .addEntry(builder.entryBuilder()
                            .startStrField(class_2561.method_43470("Build Name:"), "")
                            .setTooltip(class_2561.method_43470("This will be the build's name.\nThe build is what you just made!"))
                            .setSaveConsumer(newName -> buildName = newName)
                            .setErrorSupplier(getNameErrorSupplier())
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Should the first block be included?"), true)
                            .setTooltip(class_2561.method_43470("If this says no, building this will\nnot require that any given block\nactually placeable."))
                            .setSaveConsumer(newVal -> isHollow = !newVal)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Click this to allow current build to be discarded"), false)
                            .setTooltip(class_2561.method_43470("If this is positive, your build will be deleted!"))
                            .setSaveConsumer(newVal -> deny = newVal)
                            .build()
                    );
        } else {
            builder.setSavingRunnable(JsonConfigHelper::writeToConfig);
            builder.getOrCreateCategory(class_2561.method_43470("Options"))
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Placement-based rotation:"), snap())
                            .setTooltip(class_2561.method_43470("Builds 'sprout' out of the block you place them on"))
                            .setSaveConsumer(RePlacerConfig::setSnap)
                            .setDefaultValue(true)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Player direction-based rotation:"), spin())
                            .setTooltip(class_2561.method_43470("Builds go spin"))
                            .setSaveConsumer(RePlacerConfig::setSpin)
                            .setDefaultValue(true)
                            .build()
                    )
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("Display build rot modifier in name:"), isInclTail())
                            .setTooltip(class_2561.method_43470("This is the difference between the game displaying 'square' and 'square--fn'"))
                            .setSaveConsumer(RePlacerConfig::setInclTail)
                            .setDefaultValue(false)
                            .build()
                    )
            ;
            builder.getOrCreateCategory(class_2561.method_43470("Build Management"))
                    .addEntry(builder.entryBuilder()
                            .startStrList(class_2561.method_43470("Build Names:"), getNames())
                            .setDeleteButtonEnabled(true)
                            .setRemoveButtonTooltip(class_2561.method_43470("This will actually delete the build file!"))
                            .setAddButtonTooltip(class_2561.method_43470("This will give you errors and not actually create a build."))
                            .setTooltip(class_2561.method_43470("Changing a build name in most ways will delete it!\n\n" +
                                    "Appropriate changes:\n\n" +
                                    "if you add " + DIV + " after a build name, you can change its behavior\n" +
                                    "independent of your global rotation settings, & add it to quick access.\n" +
                                    "* " + DIV + NO + " will disable all rotation.\n" +
                                    "* " + DIV + SNAP + " will enable face snapping.\n" +
                                    "* " + DIV + SPIN + " will enable spin rotation.\n" +
                                    "* Any two (of " + NO + ", " + SNAP + ", & " + SPIN + ") can be used together.\n" +
                                    "* " + NO + " will never override " + SNAP + " or " + SPIN + "  if either is present.\n" +
                                    "* Any unspecified behavior defaults to the global setting.\n" +
                                    "* 1-9 can be used to add builds to quick access\n" +
                                    " * This does not interfere with the behavior described above"))
                            .setExpanded(true)
                            .setCellErrorSupplier(getCellErrorSupplier())
                            .setErrorSupplier(getErrorSupplier())
                            .setSaveConsumer(RePlacerConfig::buildDeleter)
                            .setDefaultValue(List.of("square"))
                            .build()
                    );
            builder.getOrCreateCategory(class_2561.method_43470("ReCorder"))
                    .addEntry(builder.entryBuilder()
                            .startBooleanToggle(class_2561.method_43470("ReCord on Menu Close:"), reCording)
                            .setSaveConsumer(RePlacerConfig::startReCording)
                            .setTooltip(class_2561.method_43470("If this is on, your block\nplacements will be recorded\nas a build until you turn\nit off"))
                            .build()
                    );
        }
        return builder;
    }

    @Override
    public ConfigScreenFactory<?> getModConfigScreenFactory() {
        JsonConfigHelper.createBuilds();
        return parent -> {
            // Return the screen here with the one you created from Cloth Config Builder
            return builder().setParentScreen(parent).build();
        };
    }

}
